@@ -125,7 +125,7 @@ KateConfigPage::KateConfigPage ( QWidget *parent, const char * )
   : KTextEditor::ConfigPage (parent)
   , m_changed (false)
 {
-  connect (this, SIGNAL(changed()), this, SLOT(somethingHasChanged ()));
+  connect (this, SIGNAL(changed()), this, SLOT(somethingHasChanged()));
 }
 
 KateConfigPage::~KateConfigPage ()
@@ -159,7 +159,7 @@ KateIndentConfigTab::KateIndentConfigTab(QWidget *parent)
   ui->cmbMode->addItems (KateAutoIndent::listModes());
 
   ui->label->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard);
-  connect(ui->label, SIGNAL(linkActivated(const QString&)), this, SLOT(showWhatsThis(const QString&)));
+  connect(ui->label, SIGNAL(linkActivated(QString)), this, SLOT(showWhatsThis(QString)));
 
   // What's This? help can be found in the ui file
 
@@ -348,7 +348,7 @@ KateViInputModeConfigTab::KateViInputModeConfigTab(QWidget *parent)
   connect(ui->chkViInputModeDefault, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkViCommandsOverride, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkViStatusBarHide, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect(ui->tblNormalModeMappings, SIGNAL(cellChanged(int, int)), this, SLOT(slotChanged()));
+  connect(ui->tblNormalModeMappings, SIGNAL(cellChanged(int,int)), this, SLOT(slotChanged()));
   connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(addNewNormalModeMappingRow()));
   connect(ui->btnRemoveSelectedNormal, SIGNAL(clicked()), this, SLOT(removeSelectedNormalMappingRow()));
   connect(ui->btnImportNormal, SIGNAL(clicked()), this, SLOT(importNormalMappingRow()));
@@ -896,15 +896,16 @@ KateSaveConfigTab::KateSaveConfigTab( QWidget *parent )
   connect( ui->cmbEncodingDetection, SIGNAL(activated(int)), this, SLOT(slotChanged()));
   connect( ui->cmbEncodingFallback, SIGNAL(activated(int)), this, SLOT(slotChanged()));
   connect( ui->cmbEOL, SIGNAL(activated(int)), this, SLOT(slotChanged()));
-  connect( ui->chkDetectEOL, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
-  connect( ui->chkEnableBOM, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
+  connect( ui->chkDetectEOL, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
+  connect( ui->chkEnableBOM, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
+  connect( ui->lineLengthLimit, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
   connect( ui->chkRemoveTrailingSpaces, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect( uiadv->chkBackupLocalFiles, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
-  connect( uiadv->chkBackupRemoteFiles, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
+  connect( uiadv->chkBackupLocalFiles, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
+  connect( uiadv->chkBackupRemoteFiles, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
   connect( uiadv->sbConfigFileSearchDepth, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
-  connect( uiadv->edtBackupPrefix, SIGNAL( textChanged ( const QString & ) ), this, SLOT( slotChanged() ) );
-  connect( uiadv->edtBackupSuffix, SIGNAL( textChanged ( const QString & ) ), this, SLOT( slotChanged() ) );
-  connect( uiadv->chkNoSync, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
+  connect( uiadv->edtBackupPrefix, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()) );
+  connect( uiadv->edtBackupSuffix, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()) );
+  connect( uiadv->chkNoSync, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
 
   internalLayout->addWidget(newWidget);
   tmpWidget->setLayout(internalLayout);
@@ -973,6 +974,8 @@ void KateSaveConfigTab::apply()
   KateDocumentConfig::global()->setEol(ui->cmbEOL->currentIndex());
   KateDocumentConfig::global()->setAllowEolDetection(ui->chkDetectEOL->isChecked());
   KateDocumentConfig::global()->setBom(ui->chkEnableBOM->isChecked());
+  
+  KateDocumentConfig::global()->setLineLengthLimit(ui->lineLengthLimit->value());
 
   KateDocumentConfig::global()->configEnd ();
   KateGlobalConfig::global()->configEnd ();
@@ -1032,6 +1035,7 @@ void KateSaveConfigTab::reload()
   ui->cmbEOL->setCurrentIndex(KateDocumentConfig::global()->eol());
   ui->chkDetectEOL->setChecked(KateDocumentConfig::global()->allowEolDetection());
   ui->chkEnableBOM->setChecked(KateDocumentConfig::global()->bom());
+  ui->lineLengthLimit->setValue(KateDocumentConfig::global()->lineLengthLimit());
 
   ui->chkRemoveTrailingSpaces->setChecked(KateDocumentConfig::global()->removeSpaces());
   uiadv->sbConfigFileSearchDepth->setValue(KateDocumentConfig::global()->searchDirConfigDepth());
@@ -1066,11 +1070,7 @@ void KateSaveConfigTab::defaults()
 //BEGIN KatePartPluginConfigPage
 KatePartPluginConfigPage::KatePartPluginConfigPage (QWidget *parent)
   : KateConfigPage (parent, "")
-  , scriptConfigPage (new KateScriptConfigPage(this))
 {
-  // FIXME: Is really needed to move all this code below to another class,
-  // since it is another tab itself on the config dialog. This means we should
-  // initialize, add and work with as we do with scriptConfigPage (ereslibre)
   QVBoxLayout *generalLayout = new QVBoxLayout;
   generalLayout->setMargin(0);
   KTabWidget *tabWidget = new KTabWidget(this);
@@ -1106,7 +1106,6 @@ KatePartPluginConfigPage::KatePartPluginConfigPage (QWidget *parent)
 
   // add all tabs
   tabWidget->insertTab(0, tmpWidget, i18n("Plugins"));
-//  tabWidget->insertTab(1, scriptConfigPage, i18n("Scripts"));
 
   generalLayout->addWidget(tabWidget);
   setLayout(generalLayout);
@@ -1118,8 +1117,6 @@ KatePartPluginConfigPage::~KatePartPluginConfigPage ()
 
 void KatePartPluginConfigPage::apply ()
 {
-  scriptConfigPage->apply();
-
   selector->updatePluginsState();
 
   KatePartPluginList &katePluginList = KatePartPluginManager::self()->pluginList();
@@ -1140,59 +1137,20 @@ void KatePartPluginConfigPage::apply ()
 
 void KatePartPluginConfigPage::reload ()
 {
-  scriptConfigPage->reload();
-
   selector->load();
 }
 
 void KatePartPluginConfigPage::reset ()
 {
-  scriptConfigPage->reset();
-
   selector->load();
 }
 
 void KatePartPluginConfigPage::defaults ()
 {
-  scriptConfigPage->defaults();
-
   selector->defaults();
 }
 //END KatePartPluginConfigPage
 
-class KateScriptNewStuff {};
-
-/*
-class KateScriptNewStuff: public KNewStuff {
-  public:
-    KateScriptNewStuff(QWidget *parent):KNewStuff("kate/scripts",parent) {}
-    virtual ~KateScriptNewStuff() {}
-    virtual bool install( const QString &fileName ) {return false;}
-    virtual bool createUploadFile( const QString &fileName ) {return false;}
-};
-*/
-//BEGIN KateScriptConfigPage
-KateScriptConfigPage::KateScriptConfigPage(QWidget *parent): KateConfigPage(parent,""), m_newStuff(new KateScriptNewStuff())
-{
-  // TODO: Please look at KateSelectConfigTab or ModeConfigPage to add
-  // a layout like we do there, to be consistent and have on all config
-  // pages the same distance to the KTabWidget edge (ereslibre)
-
-  //m_newStuff->download();
-}
-
-KateScriptConfigPage::~KateScriptConfigPage()
-{
-  delete m_newStuff;
-  m_newStuff=0;
-}
-
-void KateScriptConfigPage::apply () {
-}
-void KateScriptConfigPage::reload () {
-}
-
-//END KateScriptConfigPage
 
 //BEGIN KateHlDownloadDialog
 KateHlDownloadDialog::KateHlDownloadDialog(QWidget *parent, const char *name, bool modal)
@@ -1225,8 +1183,8 @@ KateHlDownloadDialog::KateHlDownloadDialog(QWidget *parent, const char *name, bo
        + QString("update-")
        + KateGlobal::katePartVersion()
        + QString(".xml")), KIO::Reload );
-  connect(transferJob, SIGNAL(data(KIO::Job *, const QByteArray &)),
-    this, SLOT(listDataReceived(KIO::Job *, const QByteArray &)));
+  connect(transferJob, SIGNAL(data(KIO::Job*,QByteArray)),
+    this, SLOT(listDataReceived(KIO::Job*,QByteArray)));
 //        void data( KIO::Job *, const QByteArray &data);
   resize(450, 400);
   connect(this,SIGNAL(user1Clicked()),this,SLOT(slotUser1()));
@@ -1298,6 +1256,7 @@ void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
         }
       }
       list->resizeColumnToContents(1);
+      list->sortItems(1, Qt::AscendingOrder);
     }
   }
 }
@@ -1391,8 +1350,8 @@ KateDictionaryBar::KateDictionaryBar(KateView* view, QWidget *parent)
   topLayout->setMargin(0);
   //topLayout->setSpacing(spacingHint());
   m_dictionaryComboBox = new Sonnet::DictionaryComboBox(centralWidget());
-  connect(m_dictionaryComboBox, SIGNAL(dictionaryChanged(const QString&)),
-          this, SLOT(dictionaryChanged(const QString&)));
+  connect(m_dictionaryComboBox, SIGNAL(dictionaryChanged(QString)),
+          this, SLOT(dictionaryChanged(QString)));
   connect(view->doc(), SIGNAL(defaultDictionaryChanged(KateDocument*)),
           this, SLOT(updateData()));
   QLabel *label = new QLabel(i18n("Dictionary:"), centralWidget());
@@ -1517,7 +1476,7 @@ void KateModOnHdPrompt::slotDiff()
   *m_proc << "diff" << QString(ui->chkIgnoreWhiteSpaces->isChecked() ? "-ub" : "-u")
      << "-" <<  m_doc->url().toLocalFile();
   connect( m_proc, SIGNAL(readyRead()), this, SLOT(slotDataAvailable()) );
-  connect( m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotPDone()) );
+  connect( m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotPDone()) );
 
   setCursor( Qt::WaitCursor );
   // disable the button and checkbox, to hinder the user to run it twice.
