@@ -30,8 +30,6 @@
 #include "katetextlayout.h"
 #include "katebuffer.h"
 
-#include "katevivisualmode.h"
-
 #include <limits.h>
 
 #include <kdebug.h>
@@ -262,6 +260,7 @@ void KateRenderer::paintTrailingSpace(QPainter &paint, qreal x, qreal y)
   pen.setWidthF(spaceWidth() / 3.5);
   pen.setCapStyle(Qt::RoundCap);
   paint.setPen( pen );
+  paint.setRenderHint(QPainter::Antialiasing, true);
 
   paint.drawPoint( QPointF(x, y) );
   paint.setPen( penBackup );
@@ -297,19 +296,8 @@ void KateRenderer::paintIndentMarker(QPainter &paint, uint x, uint row)
   const int height = config()->fontMetrics().height();
   const int top = 0;
   const int bottom = height-1;
-  const int h = bottom - top + 1;
 
-  // Dot padding.
-  int pad = 0;
-  if(row & 1 && h & 1) pad = 1;
-
-  for(int i = top; i <= bottom; i++)
-  {
-    if((i + pad) & 1)
-    {
-      paint.drawPoint(x + 2, i);
-    }
-  }
+  paint.drawLine(x + 2, top, x + 2, bottom);
 
   paint.setPen( penBackup );
 }
@@ -415,34 +403,6 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine( const Kate::Te
 
       renderRanges.append(selectionHighlight);
     // hihglighting for the vi visual modes
-    } else if ( m_view->getViInputModeManager()->getCurrentViMode() == VisualMode
-             || m_view->getViInputModeManager()->getCurrentViMode() == VisualLineMode
-             || m_view->getViInputModeManager()->getCurrentViMode() == VisualBlockMode ) {
-
-      KTextEditor::Range r = m_view->getViInputModeManager()->getViVisualMode()->getVisualRange();
-
-      if ( r.isValid() && (r.end().line() == line || r.start().line() == line || r.containsLine( line ) )) {
-        NormalRenderRange* selectionHighlight = new NormalRenderRange();
-        static KTextEditor::Attribute::Ptr backgroundAttribute;
-        if (!backgroundAttribute)
-          backgroundAttribute = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
-
-        backgroundAttribute->setBackground(config()->selectionColor());
-
-        if ( m_view->getViInputModeManager()->getCurrentViMode() == VisualBlockMode ) {
-          int start = r.start().column();
-          int end = r.end().column()+1;
-          if (end > m_view->doc()->lineLength( line )) {
-            end = m_view->doc()->lineLength( line );
-          }
-          selectionHighlight->addRange(new KTextEditor::Range(line, start, line, end), backgroundAttribute);
-        } else if ( m_view->getViInputModeManager()->getCurrentViMode() == VisualLineMode ) {
-          selectionHighlight->addRange(new KTextEditor::Range(line, 0, line, m_view->doc()->lineLength( line )), backgroundAttribute);
-        } else {
-          selectionHighlight->addRange(new KTextEditor::Range(r), backgroundAttribute);
-        }
-        renderRanges.append(selectionHighlight);
-      }
     }
 
     KTextEditor::Cursor currentPosition, endPosition;
@@ -495,21 +455,6 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine( const Kate::Te
 
         if(selectionsOnly) {
               assignSelectionBrushesFromAttribute(fr, *a);
-        } else if ( m_view->getCurrentViMode() == VisualMode || m_view->getCurrentViMode() == VisualLineMode ) {
-          if (m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().contains(currentPosition)) {
-            assignSelectionBrushesFromAttribute(fr, *a);
-          }
-        } else if ( m_view->getCurrentViMode() == VisualBlockMode ) {
-          if (m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().contains(currentPosition)
-              || m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().start().line() == currentPosition.line()
-              || m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().end().line() == currentPosition.line()) {
-            int c1 = m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().start().column();
-            int c2 = m_view->getViInputModeManager()->getViVisualMode()->getVisualRange().end().column();
-
-            if(currentPosition.column() >= c1 && currentPosition.column() <= c2) {
-              assignSelectionBrushesFromAttribute(fr, *a);
-            }
-          }
         }
       }
 
