@@ -4,6 +4,7 @@
    Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
    Copyright (C) 2001 Anders Lund <anders@alweb.dk>
    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
+   Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,6 +37,7 @@
 #include "katelayoutcache.h"
 #include "katetextlayout.h"
 #include "kateglobal.h"
+#include "kateviglobal.h"
 
 #include <kapplication.h>
 #include <kcharsets.h>
@@ -69,6 +71,7 @@
 #include <QtGui/QToolTip>
 #include <QtGui/QAction>
 #include <QtGui/QWhatsThis>
+#include <QtGui/QLinearGradient>
 
 #include <math.h>
 
@@ -136,16 +139,24 @@ void KateScrollBar::paintEvent(QPaintEvent *e)
   opt.pageStep = pageStep();
 
   QRect rect = style()->subControlRect(QStyle::CC_ScrollBar, &opt, QStyle::SC_ScrollBarSlider, this);
+  int sideMargin = width() - rect.width();
+  if (sideMargin < 4) sideMargin = 4;
+  sideMargin /= 2;
 
   QHashIterator<int, QColor> it = m_lines;
   while (it.hasNext())
   {
     it.next();
+    painter.setPen(it.value());
     if (it.key() < rect.top() || it.key() > rect.bottom())
     {
-      painter.setPen(it.value());
       painter.drawLine(0, it.key(), width(), it.key());
     }
+    else
+    {
+      painter.drawLine(0, it.key(), sideMargin, it.key());
+      painter.drawLine(width()-sideMargin, it.key(), width(), it.key());
+    }
   }
 }
 
@@ -176,14 +187,6 @@ void KateScrollBar::sliderChange ( SliderChange change )
   }
 }
 
-void KateScrollBar::wheelEvent(QWheelEvent *e)
-{
-  if (e->modifiers() == Qt::NoModifier)
-    return QScrollBar::wheelEvent(e);
-
-  QCoreApplication::sendEvent(m_viewInternal, e);
-}
-
 void KateScrollBar::marksChanged()
 {
   recomputeMarksPositions();
@@ -316,13 +319,12 @@ KateCmdLineEdit::KateCmdLineEdit (KateCommandLineBar *bar, KateView *view)
   , m_cmdend( 0 )
   , m_command( 0L )
 {
-  connect (this, SIGNAL(returnPressed(const QString &)),
-           this, SLOT(slotReturnPressed(const QString &)));
+  connect (this, SIGNAL(returnPressed(QString)),
+           this, SLOT(slotReturnPressed(QString)));
 
   setCompletionObject(KateCmd::self()->commandCompletionObject());
   setAutoDeleteCompletionObject( false );
-  m_cmdRange.setPattern("^([0-9$]+|\\.([+-]\\d+)?)?,([0-9$]+|\\.([+-]\\d+)?)?");
-  m_cmdExpr.setPattern("^(\\d+)([+-])(\\d+)$");
+  m_cmdRange.setPattern("^(((\\'[0-9a-z><\\+\\*\\_])|(\\d+)|\\.|\\$|\\%)([+-]((\\'[0-9a-z><\\+\\*\\_])|(\\d+)|\\.|\\$))*)(,((\\'[0-9a-z><\\+\\*\\_])|(\\d+)|\\.|\\$)([+-]((\\'[0-9a-z><\\+\\*\\_])|(\\d+)|\\.|\\$))*)?");
   m_gotoLine.setPattern("[+-]?\\d+");
 
   m_hideTimer = new QTimer(this);
@@ -333,7 +335,7 @@ KateCmdLineEdit::KateCmdLineEdit (KateCommandLineBar *bar, KateView *view)
   // wrong view when KateViewBar::hideCurrentBarWidget() is called after 4 seconds. (the timer is
   // used for showing things like "Success" for four seconds after the user has used the kate
   // command line)
-  connect(m_view, SIGNAL(focusOut (KTextEditor::View*)), m_hideTimer, SLOT(stop()));
+  connect(m_view, SIGNAL(focusOut(KTextEditor::View*)), m_hideTimer, SLOT(stop()));
 }
 
 void KateCmdLineEdit::hideEvent(QHideEvent *e)
@@ -397,6 +399,48 @@ bool KateCmdLineEdit::event(QEvent *e) {
   return KLineEdit::event(e);
 }
 
+int KateCmdLineEdit::calculatePosition( QString string) {
+
+  int pos=0;
+  QList<bool> operators_list;
+  QStringList split = string.split(QRegExp("[-+](?!([+-]|$))"));
+  QList<int> values;
+
+  foreach ( QString line, split ) {
+
+    pos+=line.size();
+    if ( pos < string.size() ) {
+      if ( string.at(pos) == '+' )
+        operators_list.push_back(true);
+      else if (string.at(pos) == '-')
+        operators_list.push_back(false);
+      else
+        Q_ASSERT(false);
+    }
+    pos++;
+
+    if ( line.contains(QRegExp("^\\d+$")))
+        values.push_back( line.toInt() );
+    else if ( line.contains(QRegExp("^\\$$")))
+        values.push_back(m_view->doc()->lines());
+    else if ( line.contains(QRegExp("^\\.$")))
+        values.push_back(m_view->cursorPosition().line()+1);
+    else if (line.contains(QRegExp("^\\'[0-9a-z><\\+\\*\\_]$")))
+        values.push_back( m_view->getViInputModeManager()->getMarkPosition(line.at(1)).line() + 1);
+
+  }
+
+  int result = values.at(0);
+  for (int i = 0; i < operators_list.size(); i++) {
+    if (operators_list.at(i) == true)
+      result += values.at(i+1);
+    else
+      result -= values.at(i+1);
+  }
+
+  return result;
+}
+
 void KateCmdLineEdit::slotReturnPressed ( const QString& text )
 {
   if (text.isEmpty()) return;
@@ -417,47 +461,22 @@ void KateCmdLineEdit::slotReturnPressed ( const QString& text )
 
   KTextEditor::Range range(-1, 0, -1, 0);
 
-  // check if a range was given
   if (m_cmdRange.indexIn(cmd) != -1 && m_cmdRange.matchedLength() > 0) {
 
-    cmd.remove( m_cmdRange );
+      cmd.remove(m_cmdRange);
 
-    QString s = m_cmdRange.capturedTexts().at(1);
-    QString e = m_cmdRange.capturedTexts().at(3);
+      QString position_string1 = m_cmdRange.capturedTexts().at(1);
+      QString position_string2 = m_cmdRange.capturedTexts().at(9);
+      int position1 = calculatePosition(position_string1);
 
-    if ( s.isEmpty() )
-      s = '.';
-    if ( e.isEmpty() )
-      e = s;
+      int position2;
+      if (position_string2 != "")
+        position2 = calculatePosition(position_string2.remove(0,1));
+      else
+        position2 = position1;
 
-    // replace '$' with the number of the last line and '.' with the current line
-    s.replace('$', QString::number( m_view->doc()->lines() ) );
-    e.replace('$', QString::number( m_view->doc()->lines() ) );
-    s.replace('.', QString::number( m_view->cursorPosition().line()+1 ) );
-    e.replace('.', QString::number( m_view->cursorPosition().line()+1 ) );
-
-    // evaluate expressions (a+b or a-b) if we have any
-    if (m_cmdExpr.indexIn(s) != -1) {
-      if (m_cmdExpr.capturedTexts().at(2) == "+") {
-        s = QString::number(m_cmdExpr.capturedTexts().at(1).toInt()
-            + m_cmdExpr.capturedTexts().at(3).toInt());
-      } else {
-        s = QString::number(m_cmdExpr.capturedTexts().at(1).toInt()
-            - m_cmdExpr.capturedTexts().at(3).toInt());
-      }
+      range.setRange(KTextEditor::Range(position1-1, 0, position2-1, 0));
     }
-    if (m_cmdExpr.indexIn(e) != -1) {
-      if (m_cmdExpr.capturedTexts().at(2) == "+") {
-        e = QString::number(m_cmdExpr.capturedTexts().at(1).toInt()
-            + m_cmdExpr.capturedTexts().at(3).toInt());
-      } else {
-        e = QString::number(m_cmdExpr.capturedTexts().at(1).toInt()
-            - m_cmdExpr.capturedTexts().at(3).toInt());
-      }
-    }
-
-    range.setRange(KTextEditor::Range(s.toInt()-1, 0, e.toInt()-1, 0));
-  }
 
   // special case: if the command is just a number with an optional +/- prefix, rewrite to "goto"
   if (m_gotoLine.exactMatch(cmd)) {
@@ -483,6 +502,11 @@ void KateCmdLineEdit::slotReturnPressed ( const QString& text )
     m_oldText = m_cmdRange.capturedTexts().at(0) + cmd;
     m_msgMode = true;
 
+    // the foollowing commands changes the focus themselves, so bar should be hiden before execution.
+    if (QRegExp("buffer|b|new|vnew|bp|bprev|bn|bnext|bf|bfirst|bl|blast").exactMatch(cmd.split(" ").at(0))){
+      emit hideRequested();
+    }
+
     // we got a range and a valid command, but the command does not inherit the RangeCommand
     // extension. bail out.
     if ( ( !ce && range.isValid() && p ) || ( range.isValid() && ce && !ce->supportsRange(cmd) ) ) {
@@ -503,7 +527,7 @@ void KateCmdLineEdit::slotReturnPressed ( const QString& text )
 
           if (msg.length() > 0)
             setText (i18n ("Success: ") + msg);
-          else
+          else if (isVisible())
             // always hide on success without message
             emit hideRequested();
         }
@@ -540,8 +564,9 @@ void KateCmdLineEdit::slotReturnPressed ( const QString& text )
   m_cmdend = 0;
 
   // the following commands change the focus themselves
-  if (!QRegExp("b(n|p)").exactMatch(cmd) && !QRegExp("(v)?new").exactMatch(cmd))
-    m_view->setFocus ();
+  if (!QRegExp("buffer|b|new|vnew|bp|bprev|bn|bnext|bf|bfirst|bl|blast").exactMatch(cmd.split(" ").at(0))) {
+    m_view->setFocus ();   
+  }
 
   if (isVisible()) {
     m_hideTimer->start(4000);
@@ -736,9 +761,8 @@ KateIconBorder::KateIconBorder ( KateViewInternal* internalView, QWidget *parent
   , m_foldingRange(0)
   , m_nextHighlightBlock(-2)
   , m_currentBlockLine(-1)
+  , m_foldingHighlightColor (KColorScheme(QPalette::Inactive, KColorScheme::Selection).background().color())
 {
-  initializeFoldingColors();
-
   setAttribute( Qt::WA_StaticContents );
   setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Minimum );
   setMouseTracking(true);
@@ -748,35 +772,10 @@ KateIconBorder::KateIconBorder ( KateViewInternal* internalView, QWidget *parent
   updateFont();
 
   m_delayFoldingHlTimer.setSingleShot(true);
-  m_delayFoldingHlTimer.setInterval(250);
+  m_delayFoldingHlTimer.setInterval(150);
   connect(&m_delayFoldingHlTimer, SIGNAL(timeout()), this, SLOT(showBlock()));
 }
 
-void KateIconBorder::initializeFoldingColors()
-{
-  // Get the schema
-  KateRendererConfig *config = m_view->renderer()->config();
-  // FIXME next 3 lines temporary until this moves to config
-  const KColorScheme scheme( QPalette::Normal );
-  const QColor middle( KColorUtils::tint( config->iconBarColor(), scheme.foreground( KColorScheme::NeutralText ).color(), 0.7 ) );
-  const QColor final( KColorUtils::tint( config->iconBarColor(), scheme.foreground( KColorScheme::PositiveText ).color(), 0.7 ) );
-
-  const QColor start( config->iconBarColor() );
-  static const int MIDFOLDINGCOLORS = MAXFOLDINGCOLORS / 2;
-  static const qreal n = 2.0 / MAXFOLDINGCOLORS;
-
-  int i, j;
-  for( i = 0; i < MIDFOLDINGCOLORS; i++ ) {
-    const qreal a = 0.9 * pow(qreal(i) * n, 1.0);
-    m_foldingColors[i] = KColorUtils::tint( start, middle, a );
-  }
-  for( j = 0; i < MAXFOLDINGCOLORS; i++, j++ ) {
-    const qreal a = 0.9 * pow(qreal(j) * n, 1.0);
-    m_foldingColors[i] = KColorUtils::tint( middle, final, a );
-  }
-}
-
-
 KateIconBorder::~KateIconBorder()
 {
   delete m_foldingRange;
@@ -863,21 +862,24 @@ QSize KateIconBorder::sizeHint() const
   int w = 0;
 
   if (m_iconBorderOn)
-    w += iconPaneWidth + 1;
+    w += iconPaneWidth + 2;
 
   if (m_annotationBorderOn)
   {
-    w += m_annotationBorderWidth + 1;
+    w += m_annotationBorderWidth + 2;
   }
 
   if (m_lineNumbersOn || (m_view->dynWordWrap() && m_dynWrapIndicatorsOn)) {
-    w += lineNumberWidth() + 1;
+    w += lineNumberWidth() + 2;
   }
 
   if (m_foldingMarkersOn)
-    w += iconPaneWidth + 1;
+    w += iconPaneWidth;
 
-  w += 4;
+  /**
+   * space for the line change system and border!
+   */
+  w += 5;
 
   return QSize( w, 0 );
 }
@@ -945,52 +947,29 @@ int KateIconBorder::lineNumberWidth() const
   return width;
 }
 
-QBrush KateIconBorder::foldingColor(KateLineInfo *info,int realLine, bool solid) {
-  int depth;
-  if (info != 0) {
-    depth = info->depth;
-  } else {
-    KateLineInfo tmp;
-    m_doc->lineInfo(&tmp, realLine);
-    depth = tmp.depth;
-  }
-
-  QColor result;
-  if (depth < MAXFOLDINGCOLORS)
-    result = m_foldingColors[depth];
-  else
-    result = m_foldingColors[MAXFOLDINGCOLORS-1];
-  if (!solid)
-    result.setAlphaF(0.4);
-
-  return QBrush( result );
-
-}
-
 void KateIconBorder::paintEvent(QPaintEvent* e)
 {
   paintBorder(e->rect().x(), e->rect().y(), e->rect().width(), e->rect().height());
 }
 
-static void paintTriangle (QPainter &painter, const QColor &baseColor, int xOffset, int yOffset, int width, int height, bool open)
+static void paintTriangle (QPainter &painter, QColor c, int xOffset, int yOffset, int width, int height, bool open)
 {
   painter.setRenderHint(QPainter::Antialiasing);
 
   qreal size = qMin (width, height);
 
-  QColor c;
-  if ( KColorUtils::luma( baseColor ) > 0.25 )
-    c = KColorUtils::darken( baseColor );
+  if ( KColorUtils::luma( c ) > 0.25 )
+    c = KColorUtils::darken( c );
   else
-    c = KColorUtils::shade( baseColor, 0.2 );
-
+    c = KColorUtils::shade( c, 0.1 );
+  
   QPen pen;
   pen.setJoinStyle (Qt::RoundJoin);
   pen.setColor (c);
   pen.setWidthF (1.5);
   painter.setPen ( pen );
 
-  painter.setBrush ( c );
+  painter.setBrush (c);
 
   // let some border, if possible
   size *= 0.6;
@@ -1071,8 +1050,8 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
 
     int lnX = 0;
 
-    p.fillRect( 0, y, w-4, h, m_view->renderer()->config()->iconBarColor() );
-    p.fillRect( w-4, y, 4, h, m_view->renderer()->config()->backgroundColor() );
+    p.fillRect( 0, y, w-5, h, m_view->renderer()->config()->iconBarColor() );
+    p.fillRect( w-5, y, 5, h, m_view->renderer()->config()->backgroundColor() );
 
     // icon pane
     if( m_iconBorderOn )
@@ -1213,19 +1192,48 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
       {
         KateLineInfo info;
         m_doc->lineInfo(&info,realLine);
+        
+        // first icon border background
+        p.fillRect(lnX, y, iconPaneWidth, h, m_view->renderer()->config()->iconBarColor());
+        // ... with possible additional folding highlighting
+        if (m_foldingRange && m_foldingRange->overlapsLine (realLine)) {
+          p.save();
 
-        QBrush brush (foldingColor(&info,realLine,true));
-        p.fillRect(lnX, y, iconPaneWidth, h, brush);
+          // use linear gradient as brush
+          QLinearGradient g(lnX, y, lnX + iconPaneWidth, y);
+          g.setColorAt(0, m_foldingHighlightColor);
+          g.setColorAt(0.3, m_foldingHighlightColor.lighter(110));
+          g.setColorAt(1, m_foldingHighlightColor);
+          p.setBrush(g);
+          p.setPen(m_foldingHighlightColor);
+
+          p.setClipRect(lnX, y, iconPaneWidth, h);
+          p.setRenderHint(QPainter::Antialiasing);
+
+          const qreal r = 4.0;
+          if (m_foldingRange->start().line() == realLine &&
+              m_viewInternal->cache()->viewLine(z).viewLine() == 0)
+          {
+            p.drawRect(lnX, y, iconPaneWidth, h + r);
+          } else if (m_foldingRange->end().line() == realLine &&
+              m_viewInternal->cache()->viewLine(z).viewLine() == m_viewInternal->cache()->viewLineCount(realLine)-1)
+          {
+            p.drawRect(lnX, y-r, iconPaneWidth, h + r);
+          } else {
+            p.drawRect(lnX, y-r, iconPaneWidth, h+2*r);
+          }
+          p.restore();
+        }
 
         if (!info.topLevel)
         {
-          if (info.startsVisibleBlock && (m_viewInternal->cache()->viewLine(z).startCol() == 0))
+          if (info.startsInVisibleBlock && m_viewInternal->cache()->viewLine(z).startCol() == 0)
           {
-            paintTriangle (p, brush.color(), lnX, y, iconPaneWidth, h, true);
+            paintTriangle (p, m_view->renderer()->config()->lineNumberColor(), lnX, y, iconPaneWidth, h, false);
           }
-          else if (info.startsInVisibleBlock && m_viewInternal->cache()->viewLine(z).startCol() == 0)
+          else if (info.startsVisibleBlock && (m_viewInternal->cache()->viewLine(z).startCol() == 0))
           {
-            paintTriangle (p, brush.color(), lnX, y, iconPaneWidth, h, false);
+            paintTriangle (p, m_view->renderer()->config()->lineNumberColor(), lnX, y, iconPaneWidth, h, true);
           }
           else
           {
@@ -1239,7 +1247,23 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
         oldInfo = info;
       }
 
-      lnX += iconPaneWidth + 2;
+      lnX += iconPaneWidth;
+    }
+
+    // modified line system
+    if (realLine > -1 && !m_doc->url().isEmpty()) {
+      // one pixel space
+      ++lnX;
+      
+      Kate::TextLine tl = m_doc->plainKateTextLine(realLine);
+      if (tl->markedAsModified()) {
+        p.setPen(Qt::red);
+        p.fillRect(lnX, y, 3, h, QColor(242, 155, 104));
+      }
+      if (tl->markedAsSavedOnDisk()) {
+        p.setPen(Qt::darkGreen);
+        p.fillRect(lnX, y, 3, h, QColor(119, 183, 83));
+      }
     }
   }
 }
@@ -1345,12 +1369,24 @@ void KateIconBorder::showBlock()
     kDebug(13025) << "new folding hl-range:" << newRange;
     m_foldingRange = m_doc->newMovingRange(newRange, KTextEditor::MovingRange::ExpandRight);
     KTextEditor::Attribute::Ptr attr(new KTextEditor::Attribute());
-    attr->setBackground(foldingColor(0, m_currentBlockLine, false));
+    
+    /**
+     * create highlighting color with alpha for the range!
+     */
+    QColor result = m_foldingHighlightColor;
+    result.setAlphaF (0.5);
+    attr->setBackground(QBrush( result ));
+    
     m_foldingRange->setView (m_view);
     // use z depth defined in moving ranges interface
     m_foldingRange->setZDepth (-100.0);
     m_foldingRange->setAttribute(attr);
   }
+  
+  /**
+   * repaint
+   */
+  repaint ();
 }
 
 void KateIconBorder::hideBlock()
@@ -1444,10 +1480,15 @@ void KateIconBorder::mouseReleaseEvent( QMouseEvent* e )
     }
 
     if ( area == FoldingMarkers) {
+      // if a folding range exists, fold this one, -> use start line of the range
+      int lineToFold = cursorOnLine;
+      if (m_foldingRange && m_foldingRange->start().line() >= 0) {
+        lineToFold = m_foldingRange->start().line();
+      }
       KateLineInfo info;
-      m_doc->lineInfo(&info,cursorOnLine);
+      m_doc->lineInfo(&info, lineToFold);
       if ((info.startsVisibleBlock) || (info.startsInVisibleBlock)) {
-        emit toggleRegionVisibility(cursorOnLine);
+        emit toggleRegionVisibility(lineToFold);
       }
     }
 
@@ -1482,14 +1523,19 @@ void KateIconBorder::mouseDoubleClickEvent( QMouseEvent* e )
   m_viewInternal->mouseDoubleClickEvent( &forward );
 }
 
+void KateIconBorder::wheelEvent(QWheelEvent *e)
+{
+  QCoreApplication::sendEvent(m_viewInternal, e);
+}
+
 void KateIconBorder::showMarkMenu( uint line, const QPoint& pos )
 {
-  if( !m_view->config()->allowMarkMenu() )
-    return;
-    
   if( m_doc->handleMarkContextMenu( line, pos ) )
     return;
 
+  if( !m_view->config()->allowMarkMenu() )
+    return;
+
   KMenu markMenu;
   KMenu selectDefaultMark;
 
@@ -1635,7 +1681,7 @@ void KateIconBorder::annotationModelChanged( KTextEditor::AnnotationModel * oldm
   if( newmodel )
   {
     connect( newmodel, SIGNAL(reset()), this, SLOT(updateAnnotationBorderWidth()) );
-    connect( newmodel, SIGNAL(lineChanged( int )), this, SLOT(updateAnnotationLine( int )) );
+    connect( newmodel, SIGNAL(lineChanged(int)), this, SLOT(updateAnnotationLine(int)) );
   }
   updateAnnotationBorderWidth();
 }
@@ -1713,7 +1759,7 @@ KateViewEncodingAction::KateViewEncodingAction(KateDocument *_doc, KateView *_vi
   d->init();
 
   connect(menu(),SIGNAL(aboutToShow()),this,SLOT(slotAboutToShow()));
-  connect(this,SIGNAL(triggered(const QString&)),this,SLOT(setEncoding(const QString&)));
+  connect(this,SIGNAL(triggered(QString)),this,SLOT(setEncoding(QString)));
 }
 
 KateViewEncodingAction::~KateViewEncodingAction()
@@ -1779,7 +1825,7 @@ QTextCodec *KateViewEncodingAction::currentCodec() const
 
 bool KateViewEncodingAction::setCurrentCodec( QTextCodec *codec )
 {
-  disconnect(this,SIGNAL(triggered(const QString&)),this,SLOT(setEncoding(const QString&)));
+  disconnect(this,SIGNAL(triggered(QString)),this,SLOT(setEncoding(QString)));
 
   int i,j;
   for (i=0;i<actions().size();++i)
@@ -1804,7 +1850,7 @@ bool KateViewEncodingAction::setCurrentCodec( QTextCodec *codec )
     }
   }
 
-  connect(this,SIGNAL(triggered(const QString&)),this,SLOT(setEncoding(const QString&)));
+  connect(this,SIGNAL(triggered(QString)),this,SLOT(setEncoding(QString)));
   return true;
 }
 
@@ -1833,6 +1879,7 @@ bool KateViewEncodingAction::setCurrentCodec( int mib )
 
 KateViewBarWidget::KateViewBarWidget (bool addCloseButton, QWidget *parent)
  : QWidget (parent)
+ , m_viewBar(0)
 {
   QHBoxLayout *layout = new QHBoxLayout (this);
 
@@ -1880,6 +1927,7 @@ void KateViewBar::addBarWidget (KateViewBarWidget *newBarWidget)
   // add new widget, invisible...
   newBarWidget->hide();
   m_stack->addWidget (newBarWidget);
+  newBarWidget->setAssociatedViewBar(this);
   connect(newBarWidget, SIGNAL(hideMe()), SLOT(hideCurrentBarWidget()));
 
   kDebug(13025)<<"add barwidget " << newBarWidget;
@@ -1887,7 +1935,12 @@ void KateViewBar::addBarWidget (KateViewBarWidget *newBarWidget)
 
 void KateViewBar::removeBarWidget (KateViewBarWidget *barWidget)
 {
-  m_stack->removeWidget(barWidget);
+  if (hasBarWidget(barWidget)) {
+    m_stack->removeWidget(barWidget);
+    barWidget->setAssociatedViewBar(0);
+    barWidget->hide();
+    disconnect(barWidget, 0, this, 0);
+  }
 }
 
 void KateViewBar::addPermanentBarWidget (KateViewBarWidget *barWidget)
@@ -1933,7 +1986,9 @@ void KateViewBar::showBarWidget (KateViewBarWidget *barWidget)
 {
   Q_ASSERT(barWidget != 0);
 
-  hideCurrentBarWidget();
+  if (barWidget != qobject_cast<KateViewBarWidget*>(m_stack->currentWidget())) {
+    hideCurrentBarWidget();
+  }
 
   // raise correct widget
   m_stack->setCurrentWidget (barWidget);
